diff --git a/apps/addressbook/java/src/net/i2p/addressbook/Daemon.java b/apps/addressbook/java/src/net/i2p/addressbook/Daemon.java
index d0c20d064d08ec938a22d04b6ddac99357826c5d..f6cb505a02d4e0bb01629f7d5962c98eb349ed53 100644
--- a/apps/addressbook/java/src/net/i2p/addressbook/Daemon.java
+++ b/apps/addressbook/java/src/net/i2p/addressbook/Daemon.java
@@ -77,7 +77,7 @@ class Daemon {
      *            client applications.
      * @param published
      *            The published AddressBook. This address book is published on
-     *            the user's eepsite so that others may subscribe to it.
+     *            the user's I2P Site so that others may subscribe to it.
      *            May be null.
      *            If non-null, overwrite with the new addressbook.
      * @param subscriptions
@@ -111,7 +111,7 @@ class Daemon {
      *            The NamingService to update, generally the root NamingService from the context.
      * @param published
      *            The published AddressBook. This address book is published on
-     *            the user's eepsite so that others may subscribe to it.
+     *            the user's I2P Site so that others may subscribe to it.
      *            May be null.
      *            If non-null, overwrite with the new addressbook.
      * @param subscriptions
diff --git a/apps/i2pcontrol/java/net/i2p/i2pcontrol/I2PControlController.java b/apps/i2pcontrol/java/net/i2p/i2pcontrol/I2PControlController.java
index bf519031bf531965f6ae55f83429c2d7edca193b..612b15606192825a19b6d89108ffd8fd7548905b 100644
--- a/apps/i2pcontrol/java/net/i2p/i2pcontrol/I2PControlController.java
+++ b/apps/i2pcontrol/java/net/i2p/i2pcontrol/I2PControlController.java
@@ -55,7 +55,7 @@ import java.util.StringTokenizer;
  * This handles the starting and stopping of Jetty
  * from a single static class so it can be called via clients.config.
  *
- * This makes installation of a new eepsite a turnkey operation.
+ * This makes installation of a new I2P Site a turnkey operation.
  *
  * Usage: I2PControlController -d $PLUGIN [start|stop]
  *
diff --git a/apps/i2ptunnel/jsp/wizard.jsp b/apps/i2ptunnel/jsp/wizard.jsp
index 1e9038e60176e9645e488c6adce19f26cb9e3fd4..b7558359fa7da0486767fde475e0c0b6d9433b34 100644
--- a/apps/i2ptunnel/jsp/wizard.jsp
+++ b/apps/i2ptunnel/jsp/wizard.jsp
@@ -134,7 +134,7 @@
                     <%=intl._t("Try this if none of the tunnel types below fit your requirements, or you don't know what type of tunnel you need.")%>
                 </td></tr>
                 <tr><td>HTTP/HTTPS</td><td>
-                    <%=intl._t("Tunnel that acts as an HTTP proxy for reaching eepsites inside I2P.")%>
+                    <%=intl._t("Tunnel that acts as an HTTP proxy for reaching I2P Sites inside I2P.")%>
                     <%=intl._t("Set your browser to use this tunnel as an http proxy, or set your \"http_proxy\" environment variable for command-line applications in GNU/Linux.")%>
                     <%=intl._t("Websites outside I2P can also be reached if an HTTP proxy within I2P is known.")%>
                 </td></tr>
@@ -161,7 +161,7 @@
                 </td></tr>
                 <tr><td>HTTP</td><td>
                     <%=intl._t("A server tunnel that is customised for HTTP connections.")%>
-                    <%=intl._t("Use this tunnel type if you want to host an eepsite.")%>
+                    <%=intl._t("Use this tunnel type if you want to host an I2P Site.")%>
                 </td></tr>
                 <tr><td>IRC</td><td>
                     <%=intl._t("A customised server tunnel for hosting IRC networks inside I2P.")%>
diff --git a/apps/routerconsole/java/src/net/i2p/router/web/PluginStarter.java b/apps/routerconsole/java/src/net/i2p/router/web/PluginStarter.java
index ae9df7209065020551df272436f34d2500900013..1fee9c6ab52f8a1e402b7f5d78cee72cacf749fd 100644
--- a/apps/routerconsole/java/src/net/i2p/router/web/PluginStarter.java
+++ b/apps/routerconsole/java/src/net/i2p/router/web/PluginStarter.java
@@ -1009,7 +1009,7 @@ public class PluginStarter implements Runnable {
             return false;
         boolean rv = group.activeCount() > 0;
         
-        // Plugins start before the eepsite, and will create the static Timer thread
+        // Plugins start before the I2P Site, and will create the static Timer thread
         // in RolloverFileOutputStream, which never stops. Don't count it.
         // Ditto HSQLDB Timer (jwebcache)
         if (rv) {
diff --git a/apps/routerconsole/java/src/net/i2p/router/web/helpers/CertHelper.java b/apps/routerconsole/java/src/net/i2p/router/web/helpers/CertHelper.java
index 926d3420ddbe51e15dbc427a62274089c8d34233..7dcd5eacb69cf514ff0234f48756669016a61dad 100644
--- a/apps/routerconsole/java/src/net/i2p/router/web/helpers/CertHelper.java
+++ b/apps/routerconsole/java/src/net/i2p/router/web/helpers/CertHelper.java
@@ -65,7 +65,7 @@ public class CertHelper extends HelperBase {
             if (!hasTunnels)
                 output(_t("SAM"), null);
 
-            // Eepsite
+            // I2P Site
             tunnelDir = new File(dir, EEPSITE_DIR);
             hasTunnels = false;
             tunnels = tunnelDir.listFiles(new FileSuffixFilter(".crt"));
diff --git a/apps/routerconsole/java/src/net/i2p/router/web/helpers/HomeHelper.java b/apps/routerconsole/java/src/net/i2p/router/web/helpers/HomeHelper.java
index 1add6d7ea4736e4f0e4a57635a66533ea9463ceb..e2c966544cb69459ad5e8b33aa6f8f98c8618bf7 100644
--- a/apps/routerconsole/java/src/net/i2p/router/web/helpers/HomeHelper.java
+++ b/apps/routerconsole/java/src/net/i2p/router/web/helpers/HomeHelper.java
@@ -83,7 +83,7 @@ public class HomeHelper extends HelperBase {
         //_x("Key Server") + S + _x("OpenPGP Keyserver") + S + "http://keys.i2p/" + S + I + "education.png" + S +
         //"killyourtv.i2p" + S + _x("Debian and Tahoe-LAFS repositories") + S + "http://killyourtv.i2p/" + S + I + "television_delete.png" + S +
         _x("MuWire") + S + _x("Easy anonymous file sharing") + S + "http://muwire.i2p/" + S + I + "muwire.png" + S +
-        //_x("Open4You") + S + _x("Free eepsite hosting with PHP and MySQL") + S + "http://open4you.i2p/" + S + I + "open4you-logo.png" + S +
+        //_x("Open4You") + S + _x("Free I2P Site hosting with PHP and MySQL") + S + "http://open4you.i2p/" + S + I + "open4you-logo.png" + S +
         //_x("Pastebin") + S + _x("Encrypted I2P Pastebin") + S + "http://zerobin.i2p/" + S + I + "paste_plain.png" + S +
         _x("Planet I2P") + S + _x("I2P News") + S + "http://planet.i2p/" + S + I + "world.png" + S +
         //_x("I2P Plugins") + S + _x("Add-on directory") + S + "http://i2pwiki.i2p/index.php?title=Plugins" + S + I + "info/plugin_link.png" + S +
@@ -307,7 +307,7 @@ public class HomeHelper extends HelperBase {
         for (App app : apps) {
             String url;
             if (app.name.equals(website) && app.url.equals("http://127.0.0.1:7658/")) {
-                // fixup eepsite link
+                // fixup I2P Site link
                 url = SummaryBarRenderer.getEepsiteURL(pm);
                 if (url == null)
                     continue;
diff --git a/apps/routerconsole/java/strings/Strings.java b/apps/routerconsole/java/strings/Strings.java
index 8fd6f802bbefa3e9d03b9d7aec123b0046868f59..7c7b437b9df82d9f9b3ae32f4bf9659e2bd024b8 100644
--- a/apps/routerconsole/java/strings/Strings.java
+++ b/apps/routerconsole/java/strings/Strings.java
@@ -22,8 +22,8 @@ class Dummy {
         _t("Web console");
         _t("SAM application bridge");
         _t("Application tunnels");
-        _t("My eepsite web server");
-        _t("I2P webserver (eepsite)");        
+        _t("My I2P Site web server");
+        _t("I2P webserver (I2P Site)");        
         _t("Browser launch at startup");
         _t("BOB application bridge");
         _t("I2P Router Console");
@@ -35,7 +35,7 @@ class Dummy {
         // keep the old string here as well for existing installs
         _t("shared clients");
         _t("IRC proxy");
-        _t("eepsite");
+        _t("I2P Site");
         _t("I2P webserver");
         _t("HTTP Proxy");        
         // hardcoded in i2psnark
diff --git a/apps/routerconsole/jsp/themes/console/light/console.css b/apps/routerconsole/jsp/themes/console/light/console.css
index 69b25ddbc01fb06d38a5d3b13d56ea86e9c9dd81..90c3db2d3439d7c8071c7afca9ee900dd8cd2203 100644
--- a/apps/routerconsole/jsp/themes/console/light/console.css
+++ b/apps/routerconsole/jsp/themes/console/light/console.css
@@ -73,6 +73,14 @@ img {
      border: none;
 }
 
+img:not(img[src$="i2plogo.png"]){     
+     image-rendering: -moz-crisp-edges;
+     image-rendering: -o-crisp-edges;
+     image-rendering: -webkit-optimize-contrast;
+     image-rendering: crisp-edges;
+     -ms-interpolation-mode: nearest-neighbor;
+}
+
 a:hover img {
      filter: drop-shadow(0 0 1px #f60);
 }
@@ -105,14 +113,11 @@ pre {
      padding: 8px;
      margin-bottom: 2px;
      text-align: center !important;
-     border: 1px solid #dee2e6;
      color: #33333f;
      font-size: 8pt;
      clear: left;/* fixes a bug in Opera */
      border-radius: 2px;
      background: #fafaff;
-     box-shadow: inset 0 0 0 1px #dee2e6;
-     filter: drop-shadow(0 0 1px #999daf);
 }
 
 .routersummary div[style="height: 36px;"] {
diff --git a/apps/susidns/src/jsp/index.jsp b/apps/susidns/src/jsp/index.jsp
index fe797e92c4e46bfffc2ebb551aca25bb8f06bb6f..0805063af0f371dc4ecc6153235d3b4638a13bd1 100644
--- a/apps/susidns/src/jsp/index.jsp
+++ b/apps/susidns/src/jsp/index.jsp
@@ -78,7 +78,7 @@
 <p>
 <%=intl._t("The addressbook application regularly polls your subscriptions and merges their content into your \"router\" address book.")%>
 <%=intl._t("Then it merges your \"local\" address book into the router address book as well.")%>
-<%=intl._t("If configured, the router address book is now written to the \"published\" address book, which will be publicly available if you are running an eepsite.")%>
+<%=intl._t("If configured, the router address book is now written to the \"published\" address book, which will be publicly available if you are running an I2P Site.")%>
 </p><p>
 <%=intl._t("The router also uses a private address book, which is not merged or published.")%>
 <%=intl._t("Hosts in the private address book can be accessed by you but their addresses are never distributed to others.")%>
diff --git a/apps/susidns/src/jsp/subscriptions.jsp b/apps/susidns/src/jsp/subscriptions.jsp
index 117bbb326aaa49b236c9c2de34177964bf6ba5ae..aa4405279ae0ff10f8591e7d42e21de3ac8f68e7 100644
--- a/apps/susidns/src/jsp/subscriptions.jsp
+++ b/apps/susidns/src/jsp/subscriptions.jsp
@@ -69,7 +69,7 @@
 <div class="help" id="helpsubs">
 <p class="help">
 <%=intl._t("The subscription file contains a list of i2p URLs.")%>
-<%=intl._t("The addressbook application regularly checks this list for new eepsites.")%>
+<%=intl._t("The addressbook application regularly checks this list for new I2P Sites.")%>
 <%=intl._t("Those URLs refer to published hosts.txt files.")%>
 <%=intl._t("The default subscription is the hosts.txt from {0}, which is updated infrequently.", "i2p-projekt.i2p")%>
 <%=intl._t("So it is a good idea to add additional subscriptions to sites that have the latest addresses.")%>
diff --git a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClient.java b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClient.java
index dff3ac99b0599776caf9b8924f9c7a1a60a29e0a..0ab4440835210c5d9a3d7d178bcdb01724a0928e 100644
--- a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClient.java
+++ b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClient.java
@@ -68,7 +68,7 @@ import net.i2p.util.PortMapper;
  * Rewrite as http://i2p/$b64key/...
  *
  * If the $site resolves with the I2P naming service, then it is directed towards
  * that eepsite, otherwise it is directed towards this client's outproxy (typically
  * "squid.i2p").  Only HTTP and HTTPS are supported (no ftp, mailto, etc).  Both GET
  * and POST have been tested, though other $methods should work.
  *
@@ -678,7 +678,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
                                         // allow i2paddresshelper=<b32>.b32.i2p syntax.
                                         /*
                                         also i2paddresshelper=name.i2p for aliases
-                                        i.e. on your eepsite put
+                                        i.e. on your I2P Site put
                                         <a href="?i2paddresshelper=name.i2p">This is the name I want to be called.</a>
                                          */
                                         Destination _dest = _context.namingService().lookup(ahelperKey);
@@ -1351,7 +1351,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
             }
 
             // Redirect to non-addresshelper URL to not clog the browser address bar
             // and not pass the parameter to the eepsite.
             // This also prevents the not-found error page from looking bad
             // Syndie can't handle a redirect of a POST
             if (ahelperPresent && !"POST".equals(method) && !"PUT".equals(method)) {
@@ -68,7 +68,7 @@ import net.i2p.util.PortMapper;
  *
  * If the $site resolves with the I2P naming service, then it is directed towards
- * that eepsite, otherwise it is directed towards this client's outproxy (typically
+ * that I2P Site, otherwise it is directed towards this client's outproxy (typically
  * "squid.i2p").  Only HTTP and HTTPS are supported (no ftp, mailto, etc).  Both GET
  * and POST have been tested, though other $methods should work.
@@ -1351,7 +1351,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
 
             // Redirect to non-addresshelper URL to not clog the browser address bar
-            // and not pass the parameter to the eepsite.
+            // and not pass the parameter to the I2P Site.
             // This also prevents the not-found error page from looking bad
             // Syndie can't handle a redirect of a POST